package com.cloudcross.ssp.web.back.main.dsp;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.ArrayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;




import com.cloudcross.ssp.base.utils.freemarker.FreemarkerTemplateProcessor;
import com.cloudcross.ssp.base.web.SimpleController;
import com.cloudcross.ssp.common.consts.Status;
import com.cloudcross.ssp.common.utils.LangUtil;
import com.cloudcross.ssp.common.utils.Pager;
import com.cloudcross.ssp.model.DspAdvertiser;
import com.cloudcross.ssp.service.IAptitudeAuditService;



@Controller
@RequestMapping("/back/main/dsp/aptitude-audit")
public class AptitudeAuditController extends SimpleController{
	
	@Autowired
	private IAptitudeAuditService iAptitudeAuditService;
	@Autowired
	private FreemarkerTemplateProcessor templateProcessor;
	/**
	 * @return 返回到dsp资质审核第一页。
	 */
	@RequestMapping("/list")
	public String list(Model model,
			@RequestParam HashMap<String, Object> paramMap,
			@RequestParam(defaultValue="1") int page) {
		//按状态搜索用
		if(paramMap.containsKey("checked")){
			if(paramMap.get("checked").equals("")) { 
				paramMap.put("checkStatus", null);
			}
			if(paramMap.get("checked").equals("1")) { 
				paramMap.put("checkStatus", 0);
			}
			if(paramMap.get("checked").equals("2")) { 
				paramMap.put("checkStatus", 2);
			}
			if(paramMap.get("checked").equals("0")) { 
				paramMap.put("checkStatus", 1);
			}
		}
		int totalRow = iAptitudeAuditService.countByParams(paramMap);
		
		Pager pager = new Pager();
		pager.setPage(page);
		pager.setTotalRow(totalRow);
		List<Map<String,Object>> auditList = iAptitudeAuditService.findByParams(paramMap, pager);
		
		model.addAllAttributes(paramMap);
		model.addAttribute("pager", pager);
		model.addAttribute("auditList", auditList);
		return page("list");
	}
	/**
	 * 用来查看资质审核
	 * @param model
	 * @param paramMap
	 * @param auditId
	 * @return
	 */
	@RequestMapping("/details")
	public String update(Model model,
			@RequestParam HashMap<String, Object> paramMap,
			@RequestParam Long dspId,
			@RequestParam Long advertiserId) {
		DspAdvertiser dspAdvertiser = iAptitudeAuditService.findById(dspId,advertiserId);
		System.out.println("luo2:" + paramMap);
		model.addAllAttributes(paramMap);
		model.addAttribute("dspAdvertiser", dspAdvertiser);
		model.addAttribute("dspId", dspId);
		model.addAttribute("advertiserId",advertiserId);
		return page("details");
	}
	
	
	@RequestMapping("check")
	public @ResponseBody String enable(@RequestParam Map<String, Object> paramMap) {
		if(paramMap.get("checkMemo")==null || paramMap.get("checkMemo")==""){
			paramMap.put("checkMemo", "");
		}
		System.out.println(paramMap.toString());
		iAptitudeAuditService.updateCheckStatus(paramMap);
		return OK;
	}
	
	@RequestMapping("/enable")
	public @ResponseBody String enable(Long[] id,Long[] advertiserId) {
		if (ArrayUtils.isNotEmpty(id)) {
			iAptitudeAuditService.updatePass(LangUtil.array2List(id),LangUtil.array2List(advertiserId),Status.enable.value);
		}
		return OK;
	}

	@RequestMapping("/disable")
	public @ResponseBody String disable(@RequestParam Long[] id,Long[] advertiserId,String memo) {
		
		if (ArrayUtils.isNotEmpty(id)) {
			iAptitudeAuditService.upDateNoPass(LangUtil.array2List(id),LangUtil.array2List(advertiserId),Status.backnopass.value,memo); 
		}
		return OK ;
	}
	//导出audit列表页Excel用
	
	@RequestMapping("/exportDataReportExcel")
	public void exportDataReportExcel(Model model,HttpServletRequest request,
			HttpServletResponse response,
			@RequestParam Map<String, Object> paramMap) {
			//model.addAttribute("advertiserId", advertiserId);
		//按状态搜索用
		if(paramMap.get("checked").equals("")) { 
			paramMap.put("checkStatus", null);
		}
		if(paramMap.get("checked").equals("1")) { 
			paramMap.put("checkStatus", 0);
		}
		if(paramMap.get("checked").equals("2")) { 
			paramMap.put("checkStatus", 2);
		}
		if(paramMap.get("checked").equals("0")) { 
			paramMap.put("checkStatus", 1);
		}
		/**
		 * 参数和list里要一样
		 */
		List<DspAdvertiser> reportList = iAptitudeAuditService.findDeliverEffectAnalysis(paramMap);
		paramMap.put("dataList", reportList);
		response.reset();
		// Content-Type:application/vnd.ms-excel;charset=utf8或者text/xml;charset=utf8
		response.setContentType("application/vnd.ms-excel;charset=utf8");
		// 设置excel文件名称
		SimpleDateFormat df2 = new SimpleDateFormat("yyyyMMddHHmmss");
		String fileName = "Report" + df2.format(new Date());
		response.setHeader("Content-Disposition", "attachment;filename="
				+ fileName + ".xls");
		// 需要对excel的列和行的总数进行指定
		int column = 9;
		paramMap.put("dataSize", (reportList.size() + 100));
		paramMap.put("column", column);
		paramMap.put("advertiserName", "广告主列表");
		paramMap.put("startDate", "2015-04-01");
		paramMap.put("endDate", "2015-06-01");
		String excelOrder = templateProcessor.processTemplate("excel/aptitudeAudit.ftl", paramMap);
		try {
			PrintWriter out = response.getWriter();
			out.write(excelOrder);
			out.flush();
			out.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
}